NSDataFromGCMicroGamepadSnapShotDataV100

Function NSDataFromGCMicroGamepadSnapShotDataV100 

pub unsafe extern "C-unwind" fn NSDataFromGCMicroGamepadSnapShotDataV100(
    snapshot_data: *mut GCMicroGamepadSnapShotDataV100,
) -> Option<Retained<NSData>>
๐Ÿ‘ŽDeprecated:

Use the -[GCController controllerWithMicroGamepad] method instead

Available on crate feature GCMicroGamepadSnapshot only.
Creates an NSData object from a v100 snapshot. If the version and size is not set in the snapshot the data will automatically have version 0x100 and sizeof(GCMicroGamepadSnapShotDataV100) set as the values implicitly.

Returns: nil if the snapshot is NULL, otherwise an NSData instance compatible with GCGamepadSnapshot.snapshotData

Safety

snapshot_data must be a valid pointer or null.