#[repr(transparent)]pub struct GCDualSenseAdaptiveTriggerStatus(pub NSInteger);GCDualSenseAdaptiveTrigger only.Expand description
Tuple Fields
0: NSIntegerImplementations
Sourceimpl GCDualSenseAdaptiveTriggerStatus
impl GCDualSenseAdaptiveTriggerStatus
Sourcepub const FeedbackNoLoad: Self
pub const FeedbackNoLoad: Self
The adaptive trigger is in feedback mode, and a resistive load has not been applied yet.
Sourcepub const FeedbackLoadApplied: Self
pub const FeedbackLoadApplied: Self
The adaptive trigger is in feedback mode, and a resistive load is applied.
Sourcepub const WeaponReady: Self
pub const WeaponReady: Self
The adaptive trigger is in weapon mode, the trigger is ready to fire, and a resistive load has not been applied yet.
Sourcepub const WeaponFiring: Self
pub const WeaponFiring: Self
The adaptive trigger is in weapon mode, the trigger is firing, and a resistive load is currently being applied.
Sourcepub const WeaponFired: Self
pub const WeaponFired: Self
The adaptive trigger is in weapon mode, the trigger has fired, and a resistive load is no longer being applied.
Sourcepub const VibrationNotVibrating: Self
pub const VibrationNotVibrating: Self
The adaptive trigger is in vibration mode, and the trigger is not vibrating.
Sourcepub const VibrationIsVibrating: Self
pub const VibrationIsVibrating: Self
The adaptive trigger is in vibration mode, and the trigger is currently vibrating.
Sourcepub const SlopeFeedbackReady: Self
pub const SlopeFeedbackReady: Self
The adaptive trigger is in slope feedback mode, the trigger is ready to apply a resistive load, but a resistive load has not been applied yet.
Sourcepub const SlopeFeedbackApplyingLoad: Self
pub const SlopeFeedbackApplyingLoad: Self
The adaptive trigger is in slope feedback mode, and a resistive load is currently being applied to the trigger.
Sourcepub const SlopeFeedbackFinished: Self
pub const SlopeFeedbackFinished: Self
The adaptive trigger is in slope feedback mode, a resistive load has previously been applied, but is no longer being applied.