pub unsafe trait GCAxisElement: GCPhysicalInputElement {
// Provided methods
unsafe fn absoluteInput(
&self,
) -> Option<Retained<ProtocolObject<dyn GCAxisInput>>>
where Self: Sized + Message { ... }
unsafe fn relativeInput(
&self,
) -> Retained<ProtocolObject<dyn GCRelativeInput>>
where Self: Sized + Message { ... }
}Available on crate features
GCAxisElement and GCPhysicalInputElement only.Expand description
Provided Methods
Sourceunsafe fn absoluteInput(
&self,
) -> Option<Retained<ProtocolObject<dyn GCAxisInput>>>
Available on crate feature GCAxisInput only.
unsafe fn absoluteInput( &self, ) -> Option<Retained<ProtocolObject<dyn GCAxisInput>>>
GCAxisInput only.The input reporting the value of the axis as the position between a lower and upper bound, if available.
Sourceunsafe fn relativeInput(&self) -> Retained<ProtocolObject<dyn GCRelativeInput>>
Available on crate feature GCRelativeInput only.
unsafe fn relativeInput(&self) -> Retained<ProtocolObject<dyn GCRelativeInput>>
GCRelativeInput only.The input reporting axis values as the change (delta) since the last event.
Certain kinds of axis elements are only able to report relative values. The tracking of a computer mouse, for example, has no fixed origin - only the change in position since the last event is reported. Some freely-rotating dials may also only report a value indicating which direction the dial was turned.