GCDirectionPadElement

Trait GCDirectionPadElement 

pub unsafe trait GCDirectionPadElement: GCPhysicalInputElement {
    // Provided methods
    unsafe fn xyAxes(&self) -> Retained<ProtocolObject<dyn GCAxis2DInput>>
       where Self: Sized + Message { ... }
    unsafe fn xAxis(&self) -> Retained<ProtocolObject<dyn GCAxisInput>>
       where Self: Sized + Message { ... }
    unsafe fn yAxis(&self) -> Retained<ProtocolObject<dyn GCAxisInput>>
       where Self: Sized + Message { ... }
    unsafe fn up(&self) -> Retained<AnyObject>
       where Self: Sized + Message { ... }
    unsafe fn down(&self) -> Retained<AnyObject>
       where Self: Sized + Message { ... }
    unsafe fn left(&self) -> Retained<AnyObject>
       where Self: Sized + Message { ... }
    unsafe fn right(&self) -> Retained<AnyObject>
       where Self: Sized + Message { ... }
}
Available on crate features GCDirectionPadElement and GCPhysicalInputElement only.
An object conforming to GCDirectionPadElementrepresents a four-way directional control element.

A direction pad element contains a common grouping of 2 axis inputs, which can also be interpreted as 2 sets of mutually exclusive button pairs. Only one button in each pair, {up, down} and {left, right}, can be pressed at any given time.

See also Apple’s documentation

Provided Methods

unsafe fn xyAxes(&self) -> Retained<ProtocolObject<dyn GCAxis2DInput>>
where Self: Sized + Message,

Available on crate feature GCAxis2DInput only.

The x,y position of the dpad input.

unsafe fn xAxis(&self) -> Retained<ProtocolObject<dyn GCAxisInput>>
where Self: Sized + Message,

Available on crate feature GCAxisInput only.

The horizontal/x-component of the dpad input.

unsafe fn yAxis(&self) -> Retained<ProtocolObject<dyn GCAxisInput>>
where Self: Sized + Message,

Available on crate feature GCAxisInput only.

The vertical/y-component of the dpad input.

unsafe fn up(&self) -> Retained<AnyObject>
where Self: Sized + Message,

Available on crate features GCLinearInput and GCPressedStateInput only.

The positive y-component of the dpad input.

unsafe fn down(&self) -> Retained<AnyObject>
where Self: Sized + Message,

Available on crate features GCLinearInput and GCPressedStateInput only.

The negative y-component of the dpad input.

unsafe fn left(&self) -> Retained<AnyObject>
where Self: Sized + Message,

Available on crate features GCLinearInput and GCPressedStateInput only.

The negative x-component of the dpad input.

unsafe fn right(&self) -> Retained<AnyObject>
where Self: Sized + Message,

Available on crate features GCLinearInput and GCPressedStateInput only.

The positive x-component of the dpad input.