pub unsafe trait GCSwitchElement: GCPhysicalInputElement {
// Provided method
unsafe fn positionInput(
&self,
) -> Retained<ProtocolObject<dyn GCSwitchPositionInput>>
where Self: Sized + Message { ... }
}Available on crate features
GCPhysicalInputElement and GCSwitchElement only.Expand description
An object conforming to
GCSwitchElementrepresents a latching switch.
A switch may be in one of several positions, and remains in its last position
after the user stops interacting with it.
See also Apple’s documentation
Provided Methods
Sourceunsafe fn positionInput(
&self,
) -> Retained<ProtocolObject<dyn GCSwitchPositionInput>>
Available on crate feature GCSwitchPositionInput only.
unsafe fn positionInput( &self, ) -> Retained<ProtocolObject<dyn GCSwitchPositionInput>>
GCSwitchPositionInput only.Get the input containing the absolute position of the switch.