GCControllerButtonTouchedChangedHandler

Type Alias GCControllerButtonTouchedChangedHandler 

pub type GCControllerButtonTouchedChangedHandler = *mut DynBlock<dyn Fn(NonNull<GCControllerButtonInput>, c_float, Bool, Bool)>;
Available on crate features block2 and GCControllerButtonInput and GCControllerElement only.
Set this block if you want to be notified when the touched state on this button changes.

Parameter button: the element that has been modified.

Parameter value: the value the button was set to at the time the valueChangedHandler fired.

Parameter pressed: the pressed state of the button at the time the valueChangedHandler fired.

Parameter touched: the touched state of the button at the time the valueChangedHandler fired.

See: value

See: pressed

See also Apple’s documentation