GCControllerDirectionPadValueChangedHandler

Type Alias GCControllerDirectionPadValueChangedHandler 

pub type GCControllerDirectionPadValueChangedHandler = *mut DynBlock<dyn Fn(NonNull<GCControllerDirectionPad>, c_float, c_float)>;
Available on crate features block2 and GCControllerDirectionPad and GCControllerElement only.
Set this block if you want to be notified when the value on this axis changes.

Parameter dpad: the direction pad collection whose axis have been modified.

Parameter xValue: the value the x axis was set to at the time the valueChangedHandler fired.

Parameter yValue: the value the y axis was set to at the time the valueChangedHandler fired.

See also Apple’s documentation