GCControllerTouchpadHandler

Type Alias GCControllerTouchpadHandler 

pub type GCControllerTouchpadHandler = *mut DynBlock<dyn Fn(NonNull<GCControllerTouchpad>, c_float, c_float, c_float, Bool)>;
Available on crate features block2 and GCControllerElement and GCControllerTouchpad only.
Set this block if you want to be notified when an axis or the touch state changes.

Parameter touchpad: the touchpad collection whose axes or touch state has been modified.

Parameter xValue: the value x axis was set to at the time the handler fired.

Parameter yValue: the value y axis was set to at the time the handler fired.

Parameter buttonValue: the value of the touch surface button at the time the handler fired.

Parameter buttonPressed: the pressed state of the touch surface button at the time the handler fired.

See also Apple’s documentation