GCKeyboardValueChangedHandler

Type Alias GCKeyboardValueChangedHandler 

pub type GCKeyboardValueChangedHandler = *mut DynBlock<dyn Fn(NonNull<GCKeyboardInput>, NonNull<GCControllerButtonInput>, GCKeyCode, Bool)>;
Available on crate features block2 and GCControllerButtonInput and GCControllerElement and GCKeyboardInput and GCKeyCodes and GCPhysicalInputProfile and objc2-core-foundation only.
Set this block if you want to be notified when a value of a key changed. If multiple keys have changed this block will be called cd for each key that changed.

Parameter keyboard: this keyboard that is being used to map the raw input data into logical values on keyboard keys.

Parameter key: the key that has been modified

Parameter pressed: the state of the key at the moment of block calling

See also Apple’s documentation