pub unsafe trait GCPhysicalInputElement: NSObjectProtocol {
// Provided methods
unsafe fn aliases(&self) -> Retained<NSSet<NSString>>
where Self: Sized + Message { ... }
unsafe fn localizedName(&self) -> Option<Retained<NSString>>
where Self: Sized + Message { ... }
unsafe fn sfSymbolsName(&self) -> Option<Retained<NSString>>
where Self: Sized + Message { ... }
}Available on crate feature
GCPhysicalInputElement only.Expand description
The
GCPhysicalInputElementprotocol is a base protocol for specific types
of elements that represent controls on a device.
See also Apple’s documentation
Provided Methods
Sourceunsafe fn aliases(&self) -> Retained<NSSet<NSString>>
unsafe fn aliases(&self) -> Retained<NSSet<NSString>>
The set of aliases that can be used to access this element with keyed subscript notation.
Sourceunsafe fn localizedName(&self) -> Option<Retained<NSString>>
unsafe fn localizedName(&self) -> Option<Retained<NSString>>
The element’s localized display name.
This is the string that your app should display in any on-screen messages instructing the user to interact with the control. For example:
“Press (buttonA.localizedName) to jump!”
Do not cache this value - it can change when the user remaps controls.